@@ -21,12 +21,11 @@ Agent - Activist of the Art World
 
 =head1 SYNOPSIS
 
-use Art::Wildlife;
+  use Art::Wildlife;
 
-my $agent = Art::Wildlife->new_agent( name => $f->person_name );
+  my $agent = Art::Wildlife->new_agent( name => $f->person_name );
 
-# "That's interesting"
-$agent->participate;
+  $agent->participate;    # ==>  "That's interesting"
 
 =head1 DESCRIPTION
 
