@@ -5,7 +5,7 @@ package Art::World;
 # use Art::Agent;
 #has Art::Agent::Artist @.artists;
 
-our $VERSION = '0.15_03';
+our $VERSION = '0.15_04';
 
 use Zydeco;
 
@@ -41,7 +41,6 @@ If a correct API is reached, we'll try to build a "game of art" frontend.
 
 =end html
 
-
 =over
 
 =item 01 Idea is the first step of process
@@ -130,6 +129,38 @@ If a correct API is reached, we'll try to build a "game of art" frontend.
 
 This is a long term continuation of an art project started circa 2006.
 
+In 2008 I benefited of an artist residency in an agricultural college with a
+creation grant of 10 000€. I urged to keep go on my Art World and Creative
+Processes schema projects initiated during art school. It didn't went very well
+because the then local state Plastic Art I<Inspector> didn't like what I was
+doing with her money and strongly advised to change orientation. In my idea, it
+was a perfect thing that the instutition itself would exhibit it's inherent
+processes and operations. In the end, there were an exhibition, but she didn't
+come to the opening.
+
+=begin html
+
+<p>
+  <img alt="Pencil schema with mountains" src="https://gitlab.com/smonff/art-world/-/raw/master/spec/schema_v4.png"
+    width="600px">
+</p>
+
+=end html
+
+Then I almost got hit by a fellow artist who was participating at a collective
+exhibition mostly for the money and not for the fun.
+
+In 2008, I finally decided to start a training to learn programming and being
+able to design a proper database and system for I<managing a virtual Art
+World>. I became a web developer, but I totally forgot the main aim. Sometimes I
+thought about it, and in 2017, I restarted my project while getting into Raku
+(it was still Perl6 at this time), but learning Raku was too much effort and I
+abandonned again.
+
+Ten years later I am still on it. This project is L<following me in my
+dreams|https://smonff.gitlab.io/art-school-story/>. I'll give it another try.
+
+
 =head1 AUTHOR
 
 Sébastien Feugère <sebastien@feugere.net>
